# piifinder

A CLI tool to scan for PII (Personally Identifiable Information) in your source code or text files, using Microsoft's Presidio library.

## Installation

```bash
pip install piifinder
```

## Usage

```
piifinder scan path/to/scan
```
